# Examples and documentation

This page provide three examples of input files with increasing flexibility as to the layout of the diagram, and for the 
last example, the kind of data that can be provided. 
It also provides some information on the 'format' of the files, which is supplemented by the information in the files
themselves.
To make 'ember' diagrams from your own data, start from the Basic format below, which contains a standard IPCC-style data table
(but note that no files are 'from the IPCC' or under its responsibility: see [more information](/more)).

## Basic format

### SRCCL figure SPM.2 B

[Basic format example](/examples/Basic-fmt-SRCCL.xlsx)

The basic format is identical to the presentation of tables provided in the supplementary material of
the three last IPCC Special Reports. In particular, the data provided here was taken from table SM7.6 of
the Special Report on Climate change and Land. The resulting 'burning ember diagram' appears in the Summary
for Policymakers as 
[figure 2, panel B (IPCC website)](https://www.ipcc.ch/site/assets/uploads/2019/08/SPM2-approval-FINAL-1.pdf).

The table indicates the level of global warming which corresponds to "risk transitions", i.e. changes
from one risk level to the next, according to a standard scale used by the IPCC in several of its reports.

In addition, this example contains a few parameters, at the top or the Excel worksheet.
They provide additional information which is specific to the graphic: 

- `haz_top_value = 3` => the vertical scale is limited to +3°C (the `=` sign is used here for clarity, in the sheet
   the name of the parameter and its value are simply in adjacent cells)

- `haz_name` and `haz_unit` => the vertical scale ('hazard level') may relate to 
indicators of change other than mean temperature, for example the rate of change or ocean pH.

- `leg_title` specifies a title to be written on top of the legend (colour bar); it is copied here from SRCCL SPM.2; it this title is not appropriate for your graphic,
just delete or replace it.

While it is not used in this example, you may move the legend to the right instead of the bottom, by adding

- `leg_pos = right`

None of these parameters is mandatory: there are default values.

## Basic format + layout parameters sheet

The "Basic format" (above) is limited to a few parameters which are sufficient to reproduce most types
or 'burning ember' figures published so far, but with limitations regarding layout details.
To avoid cluttering the sheet that contains the assessment data, we add a sheet containing layout parameters.

[Basic+layout example](/examples/Basic+layout-SRCCL.xlsx)

The "Basic+layout" example includes the additional 'layout' sheet with all its parameters.
This particular example illustrates the following:

- the caption is on the right (`leg_pos = right`). This is one of the few parameters which can be either in the main
data sheet (as mentioned above) or in the layout data sheet (here); when the layout sheet is present, we feel it more 
logical to have theses parameters in the layout sheet. 
Detail: there are 4 permitted values for `leg_pos`: under, right, in-grid-horizontal and in-grid-vertical; 
the later applies to complex figures in which there are at least two lines of "ember" groups, which form a "grid".

- there are 4 main temperature levels (0, 1, 2, 3). This is set by the first value of the parameter `haz_grid_lines`, 
which is set to 3 (and adapted by the software to have 4 'nice' levels). In addition, there is a line at 1.5°C:
this is set in the next columns on the right of the main value (3) of `haz_grid_lines`; there can be more than one 
'prescribed' level.

- changes in the way *confidence levels* are indicated on the diagram. While using a number of dots is the most recent 
IPCC practice (see SROCC SPM.3), letters (L for Low confidence, H for Medium, ...) where used in the SRCCL.  
The names of confidence levels (Low, Medium...) used in the data sheet are translated to symbols for the diagram 
according to a table which is at the bottom of the 'layout' sheet. You could fill anything as input (`conf_levels_file`)
and anything as output (`conf_levels_graph`), so even translations could potentially be done in this way.

The resulting figure is significantly closer to the layout of the published figure 
([figure 2, panel B (IPCC website)](https://www.ipcc.ch/site/assets/uploads/2019/08/SPM2-approval-FINAL-1.pdf));
this shows the flexibility generated by using the 'layout' sheet.

There are other options illustrated in this Excel file, such as the possibility to sort the embers.
It is thus possible to generate different diagrams without changing the 'data' sheet (i.e. instead
of manually moving data lines to re-order embers, which could possibly result in errors, you may list the ember names 
in the desired order in the 'layout' sheet). It also possible to sort *groups* of embers;
groups are tables in the data sheet, separated by blank lines.
The position of many elements can be adjusted by changing parameters according to their
names from the diagram included in the Excel file.

## Fullflex format

[Fullflex format example](/examples/Flex-fmt-RFC.xlsx)

The "full flexibility" format provides more flexibilty regarding the input data.
The first sheet from this Excel workbook is completely different from the first sheet of the 'basic format' above.
It provides more control on the risk levels, e.g. a transition 
that has a faster increase in risk at some temperature level. 
The second sheet is the 'layout' sheet described above, 
and the last sheet defines the colors and associated risk levels.
This format was designed for a paper which is now submitted. The data provided here is only an example 
for the format, and should not be used. Further information will come with the paper when published,
with the complete data in the 'supplementary material'.

## Further improvements & documentation

Comments are welcome. We will make our best to respond to requests regarding improvement,
documentations, or specific features, adapting the application if needed.
(see contact below).